import json
from datetime import datetime, timezone
from . import __version__


def main() -> None:
    payload = {
        "name": "acong-tech-canary",
        "version": __version__,
        "registry": "pypi",
        "ok": True,
        "ts": datetime.now(timezone.utc).isoformat(),
    }
    print(json.dumps(payload, indent=2))
